==> pywebify-0.2.5.tar.gz: pywebify-0.2.5/setup.py <==
"""A setuptools based setup module.
See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()
with open(path.join('pywebify', 'version.txt'), 'r') as input:
    __version__ = input.readlines()[0]

setup(
    name='pywebify',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version=__version__,

    description='Browser-based html/image file report builder',
    long_description='Browser-based html/image file report builder',

    # The project's main homepage.
    url='https://github.com/endangeredoxen/pywebify',
    download_url = 'https://github.com/endangeredoxen/pywebify/archive/v0.2.5.tar.gz',

    # Author details
    author='Steve Nicholes',
    author_email='endangeredoxen@users.noreply.github.com',

    # Choose your license
    license='GPLv3',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    # classifiers=[
    #     # How mature is this project? Common values are
    #     #   3 - Alpha
    #     #   4 - Beta
    #     #   5 - Production/Stable
    #     'Development Status :: 5',

    #     # Indicate who your project is intended for
    #     'Intended Audience :: Engineers/Scientists',
    #     'Topic :: Data Analysis',

    #     # Pick your license as you wish (should match "license" above)
    #     'License :: GPL v3 License',

    #     # Specify the Python versions you support here. In particular, ensure
    #     # that you indicate whether you support Python 2, Python 3 or both.
    #     'Programming Language :: Python :: 3.6',
    # ],

    # What does your project relate to?
    keywords=['data', 'web report'],

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=['contrib', 'docs']),

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    # dependency_links = [],

    install_requires=['pandas','numpy','natsort','fivecentfileio==0.2.9'],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    extras_require={

    },

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    package_data={
        'pywebify': ['config.ini', 'img/*', 'js/*', 'templates/css/*',
        'templates/html/*', 'templates/jinja/*', 'setup.txt'],
    },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # data_files=[('C:/my_data', ['pywebify/config.ini'])],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    # entry_points={
    #     'console_scripts': [
    #         'sample=sample:main',
    #     ],
    # },
)

==> pywebify-0.2.6.tar.gz: pywebify-0.2.6/setup.py <==
"""A setuptools based setup module.
See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()
with open(path.join('pywebify', 'version.txt'), 'r') as input:
    __version__ = input.readlines()[0]

setup(
    name='pywebify',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version=__version__,

    description='Browser-based html/image file report builder',
    long_description='Browser-based html/image file report builder',

    # The project's main homepage.
    url='https://github.com/endangeredoxen/pywebify',
    download_url = 'https://github.com/endangeredoxen/pywebify/archive/v%s.tar.gz' % __version__,

    # Author details
    author='Steve Nicholes',
    author_email='endangeredoxen@users.noreply.github.com',

    # Choose your license
    license='GPLv3',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    # classifiers=[
    #     # How mature is this project? Common values are
    #     #   3 - Alpha
    #     #   4 - Beta
    #     #   5 - Production/Stable
    #     'Development Status :: 5',

    #     # Indicate who your project is intended for
    #     'Intended Audience :: Engineers/Scientists',
    #     'Topic :: Data Analysis',

    #     # Pick your license as you wish (should match "license" above)
    #     'License :: GPL v3 License',

    #     # Specify the Python versions you support here. In particular, ensure
    #     # that you indicate whether you support Python 2, Python 3 or both.
    #     'Programming Language :: Python :: 3.6',
    # ],

    # What does your project relate to?
    keywords=['data', 'web report'],

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=['contrib', 'docs']),

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    # dependency_links = [],

    install_requires=['pandas','numpy','natsort','fivecentfileio'],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    extras_require={

    },

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    package_data={
        'pywebify': ['config.ini', 'img/*', 'js/*', 'templates/css/*',
        'templates/html/*', 'templates/jinja/*', 'setup.txt', 'version.txt'],
    },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # data_files=[('C:/my_data', ['pywebify/config.ini'])],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    # entry_points={
    #     'console_scripts': [
    #         'sample=sample:main',
    #     ],
    # },
)
